#include <stdio.h>
#include <gtk/gtk.h>

void makeTable(int, int, int);
void ChangeLabel(int p, int d, char *name);
void add_to_dialog_viewset(int cnum);

gboolean
on_main_drawingarea_configure_event        (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_main_drawingarea_expose_event           (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_main_drawingarea_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_main_drawingarea_motion_notify_event    (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_main_drawingarea_button_release_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_window_ex_key_press_event             (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_window_ex_key_release_event           (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_window_ex_focus_out_event             (GtkWidget       *widget,
                                        GdkEventFocus   *event,
                                        gpointer         user_data);

void
on_quit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_viewset_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_send_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_lock_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_version_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_dialog_viewset_list_select_child    (GtkList         *list,
                                        GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_window_ex_delete_event                (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_button_press_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_button_release_event (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_configure_event      (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_expose_event         (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_motion_notify_event    (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

void
on_window_ex_togglebutton_toggled       (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_screen_expand_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_screen_ctrl_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_screen_lock_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_screen_send_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_screen_send_stop_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_dialog_send_checkbutton1_toggled    (GtkToggleButton *togglebutton,
		                        gpointer         user_data);

void
on_dialog_send_checkbutton2_toggled    (GtkToggleButton *togglebutton,
		                        gpointer         user_data);

void
on_dialog_send_checkbutton3_toggled    (GtkToggleButton *togglebutton,
		                        gpointer         user_data);

void
on_dialog_send_checkbutton4_toggled    (GtkToggleButton *togglebutton,
		                        gpointer         user_data);

void
on_dialog_send_comboboxentry1_changed  (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_dialog_send_comboboxentry2_changed  (GtkComboBox     *combobox,
                                        gpointer         user_data);


void
on_dialog_lock_checkbutton1_toggled    (GtkToggleButton *togglebutton,
		                        gpointer         user_data);

void
on_dialog_lock_checkbutton2_toggled    (GtkToggleButton *togglebutton,
		                        gpointer         user_data);

gboolean
on_main_window_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_dialog_viewset_delete_event         (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_viewset_button_tab_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_viewset_button_moveupg_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_viewset_button_moveup_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_viewset_button_movedown_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_viewset_button_movedowng_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_viewset_buttonOK_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_viewset_buttonCancel_clicked (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_IDinput_delete_event         (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_IDinput_entry_changed        (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_dialog_IDinput_buttonOK_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_IDinput_buttonCancel_clicked (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_send_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_send_checkbutton0_toggled    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_dialog_send_buttonOK_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_send_buttonCancel_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_send_buttonApply_clicked     (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_lock_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_lock_checkbutton0_toggled    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_dialog_lock_buttonOK_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_lock_buttonCancel_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_lock_buttonApply_clicked     (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_quit_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_quit_buttonOK_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_quit_buttonCancel_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_notebook_switch_page                (GtkNotebook     *notebook,
					GtkNotebookPage *page,
					guint            page_num,
					gpointer         user_data);

gboolean
on_dialog_version_delete_event         (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_version_buttonOK_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_send_fullscreen_radiobutton_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_dialog_send_window_radiobutton_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_window_ex_delete_event              (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_window_ex_key_press_event           (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_window_ex_key_release_event         (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_window_ex_focus_out_event           (GtkWidget       *widget,
                                        GdkEventFocus   *event,
                                        gpointer         user_data);

void
on_window_ex_togglebutton_toggled      (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_button_press_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_button_release_event (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_configure_event      (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_expose_event         (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_motion_notify_event  (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_aspectframe_configure_event         (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_aspectframe_expose_event            (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_button_press_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_button_release_event (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_configure_event      (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_expose_event         (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_ex_motion_notify_event  (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_aspectframe_configure_event         (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_aspectframe_expose_event            (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

void
on_dialog_lock_checkbutton0_toggled    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_frame_ulist_press_event             (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_dialog_opeState_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_opeState_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_dialog_opeState_buttonApply_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_opeState_buttonCancel_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_opeState_buttonOK_clicked    (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_main_window_configure_event         (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_window_ex_configure_event           (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);
